@@ -2,6 +2,8 @@
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
 
+from mezzanine.conf import settings
+from mezzanine.core.fields import FileField
 from mezzanine.core.models import Displayable, Ownable, RichText, Slugged
 from mezzanine.generic.fields import CommentsField, RatingField
 
@@ -16,6 +18,8 @@ class BlogPost(Displayable, Ownable, RichText):
     allow_comments = models.BooleanField(default=True)
     comments = CommentsField(verbose_name=_("Comments"))
     rating = RatingField(verbose_name=_("Rating"))
+    featured_image = FileField(verbose_name=_("Featured Image"), null=True,
+                               upload_to="blog", max_length=255, blank=True)
 
     class Meta:
         verbose_name = _("Blog post")
@@ -24,7 +28,15 @@ class BlogPost(Displayable, Ownable, RichText):
 
     @models.permalink
     def get_absolute_url(self):
-        return ("blog_post_detail", (), {"slug": self.slug})
+        url_name = "blog_post_detail"
+        kwargs = {"slug": self.slug}
+        if settings.BLOG_URLS_USE_DATE:
+            url_name = "blog_post_detail_date"
+            month = str(self.publish_date.month)
+            if len(month) == 1:
+                month = "0" + month
+            kwargs.update({"month": month, "year": self.publish_date.year})
+        return (url_name, (), kwargs)
 
 
 class BlogCategory(Slugged):
