@@ -330,6 +330,40 @@ register_setting(
     default="mezzanine.core.forms.TinyMceWidget",
 )
 
+register_setting(
+    name="RICHTEXT_ALLOWED_TAGS",
+    description=_("List of HTML tags that won't be stripped from "
+        "``RichTextField`` instances."),
+    editable=False,
+    default=("a", "abbr", "acronym", "address", "area", "b", "bdo", "big",
+        "blockquote", "br", "button", "caption", "center", "cite", "code",
+        "col", "colgroup", "dd", "del", "dfn", "dir", "div", "dl", "dt",
+        "em", "fieldset", "font", "form", "h1", "h2", "h3", "h4", "h5",
+        "h6", "hr", "i", "img", "input", "ins", "kbd", "label", "legend",
+        "li", "map", "menu", "ol", "optgroup", "option", "p", "pre", "q",
+        "s", "samp", "select", "small", "span", "strike", "strong", "sub",
+        "sup", "table", "tbody", "td", "textarea", "tfoot", "th", "thead",
+        "tr", "tt", "u", "ul", "var", "wbr"),
+)
+
+register_setting(
+    name="RICHTEXT_ALLOWED_ATTRIBUTES",
+    description=_("List of HTML attributes that won't be stripped from "
+        "``RichTextField`` instances."),
+    editable=False,
+    default=("abbr", "accept", "accept-charset", "accesskey", "action",
+        "align", "alt", "axis", "border", "cellpadding", "cellspacing",
+        "char", "charoff", "charset", "checked", "cite", "class", "clear",
+        "cols", "colspan", "color", "compact", "coords", "datetime", "dir",
+        "disabled", "enctype", "for", "frame", "headers", "height", "href",
+        "hreflang", "hspace", "id", "ismap", "label", "lang", "longdesc",
+        "maxlength", "media", "method", "multiple", "name", "nohref",
+        "noshade", "nowrap", "prompt", "readonly", "rel", "rev", "rows",
+        "rowspan", "rules", "scope", "selected", "shape", "size", "span",
+        "src", "start", "style", "summary", "tabindex", "target", "title",
+        "type", "usemap", "valign", "value", "vspace", "width", "xml:lang"),
+)
+
 register_setting(
     name="RICHTEXT_FILTER",
     description=_("Dotted path to the function to call on a ``RichTextField`` "
